KERNEL_VERSION=2.6.18.1
KERNEL_URL=http://www.kernel.org/pub/linux/kernel/v2.6/
KERNEL_SOURCE=linux-$(KERNEL_VERSION).tar.bz2
KERNEL_DIR=$(BUILD_DIR)/kernel
KERNEL_SRC_DIR=$(KERNEL_DIR)/linux-$(KERNEL_VERSION)
KERNEL_STAMP_DIR=$(KERNEL_DIR)/stamps
KERNEL_LOG_DIR=$(KERNEL_DIR)/logs

TINY_DIR=$(PACKAGE_DIR)/kernel/tiny

KERNEL_PATCHES  = $(PACKAGE_DIR)/kernel/ext3.patch

# Add in the linux-tiny patches 
KERNEL_PATCHES += $(shell ls $(TINY_DIR)/*.patch)

ifeq ($(VERBOSE),y)
KERNEL_BUILD_LOG=/dev/stdout
KERNEL_INSTALL_LOG=/dev/stdout
else
KERNEL_BUILD_LOG=$(KERNEL_LOG_DIR)/build.log
KERNEL_INSTALL_LOG=$(KERNEL_LOG_DIR)/install.log
endif

$(SOURCE_DIR)/$(KERNEL_SOURCE):
	@ mkdir -p $(SOURCE_DIR)
	@ wget -P $(SOURCE_DIR) $(KERNEL_URL)/$(KERNEL_SOURCE)

$(KERNEL_STAMP_DIR)/.unpacked: $(SOURCE_DIR)/$(KERNEL_SOURCE)
	@ echo "Unpacking kernel..."
	@ tar -C $(KERNEL_DIR) -jxf $(SOURCE_DIR)/$(KERNEL_SOURCE)
	@ touch $@	

$(KERNEL_STAMP_DIR)/.patched: $(KERNEL_STAMP_DIR)/.unpacked
	@ echo "Patching kernel..."
	@ $(BIN_DIR)/doquilt.sh $(KERNEL_SRC_DIR) $(KERNEL_PATCHES)
	@ touch $@

$(KERNEL_SRC_DIR)/.config: $(KERNEL_STAMP_DIR)/.patched
	@ cat $(PACKAGE_DIR)/kernel/conf/defconfig | sed -e s:^CONFIG_LOCALVERSION=.*:CONFIG_LOCALVERSION=\"$(ROM_VERSION)\": > $(KERNEL_SRC_DIR)/.config

$(KERNEL_SRC_DIR)/arch/x86_64/boot/bzImage: $(KERNEL_SRC_DIR)/.config
	@ echo "Building kernel..."
	@ $(MAKE) -C $(KERNEL_SRC_DIR) \
	KERNEL_CC=$(CC) KERNEL_LD=$(LD) > $(KERNEL_BUILD_LOG) 2>&1

$(OUTPUT_DIR)/bzImage: $(KERNEL_SRC_DIR)/arch/x86_64/boot/bzImage
	@ install -d $(OUTPUT_DIR)
	@ install -m 0644 $< $@ 

$(OUTPUT_DIR)/vmlinux: $(KERNEL_SRC_DIR)/arch/x86_64/boot/bzImage
	@ install -d $(OUTPUT_DIR)
	@ install -m 0644 $(KERNEL_SRC_DIR)/vmlinux $@

$(KERNEL_STAMP_DIR)/.headers: $(KERNEL_SRC_DIR)/.config $(STAGING_DIR)/host/bin/unifdef
	@ echo "Installing kernel headers..."
	@( export PATH=$(PATH):$(STAGING_DIR)/host/bin; \
	$(MAKE) -C $(KERNEL_SRC_DIR) \
	INSTALL_HDR_PATH=$(STAGING_DIR)/ headers_install > $(KERNEL_INSTALL_LOG) 2>&1)
	@ touch $@

$(KERNEL_STAMP_DIR) $(KERNEL_LOG_DIR):
	@ mkdir -p $@

kernel: $(KERNEL_STAMP_DIR) $(KERNEL_LOG_DIR) $(OUTPUT_DIR)/bzImage $(OUTPUT_DIR)/vmlinux $(KERNEL_STAMP_DIR)/.headers

kernel-clean:
	@ echo "Cleaning kernel..."
	@ $(MAKE) -C $(KERNEL_SRC_DIR) clean > /dev/null 2>&1

kernel-distclean:
	@ rm -rf $(KERNEL_DIR)/*

kernel-bom:
	@ echo "Package: kernel"
	@ echo "Source: $(KERNEL_URL)/$(KERNEL_SOURCE)"
	@ echo -n "Patches: (local) "
	@ for file in $(KERNEL_PATCHES); do \
		echo -n "`basename $$file` "; \
	  done
	@ echo ""
	@ echo ""
